Kw

Enum Kw 

pub enum Kw {
Show 43 variants Ht, Wid, Rad, Diam, Thick, Scaled, From, To, At, With, By, Then, Continue, Chop, Same, Cw, Ccw, Of, The, Way, Between, And, Here, Last, Fill, Nth, Print, Copy, Reset, Exec, Sh, Command, Define, Undef, Rand, If, Else, For, Do, Sprintf, Animate, After, Delay,
}
General keywords: attributes, ordinals, control words, commands.

Variants



Ht



Wid



Rad



Diam



Thick



Scaled



From



To



At



With



By



Then



Continue



Chop



Same



Cw



Ccw



Of



The



Way



Between



And



Here



Last



Fill



Nth



Print



Copy



Reset



Exec



Sh



Command



Define



Undef



Rand



If



Else



For



Do



Sprintf



Animate



After



Delay